@@ -1,8 +1,8 @@
 #' Convert a VCF file into a pooldata object.
 #' @description Convert VCF files into a pooldata object.
 #' @param vcf.file The name (or a path) of the Popoolation sync file (might be in compressed format)
-#' @param poolsizes A numeric vector with haploid pool sizes
-#' @param poolnames A character vector with the names of pool
+#' @param poolsizes A numeric vector with haploid pool sizes (if NA haploid pools sizes are set to a default value of 100)
+#' @param poolnames A character vector with the names of pool (if NA sample names are retrieved from the vcf header)
 #' @param min.rc Minimal allowed read count per base (options silenced for VarScan vcf). Bases covered by less than min.rc reads are discarded and considered as sequencing error. For instance, if nucleotides A, C, G and T are covered by respectively 100, 15, 0 and 1 over all the pools, setting min.rc to 0 will lead to discard the position (the polymorphism being considered as tri-allelic), while setting min.rc to 1 (or 2, 3..14) will make the position be considered as a SNP with two alleles A and C (the only read for allele T being disregarded). For VarScan vcf, markers with more than one alternative allele are discarded because the VarScan AD field only contains one alternate read count.
 #' @param min.cov.per.pool Minimal allowed read count (per pool). If at least one pool is not covered by at least min.cov.perpool reads, the position is discarded
 #' @param max.cov.per.pool Maximal allowed read count (per pool). If at least one pool is covered by more than min.cov.perpool reads, the position is discarded
@@ -28,11 +28,12 @@
 #' @export
 vcf2pooldata<-function(vcf.file="",poolsizes=NA,poolnames=NA,min.cov.per.pool=-1,min.rc=1,max.cov.per.pool=1e6,min.maf=-1,remove.indels=FALSE,min.dist.from.indels=0,nlines.per.readblock=1000000,verbose=TRUE){
   if(nchar(vcf.file)==0){stop("ERROR: Please provide the name of the vcf file as generated by e.g. VarScan")}
-  if(sum(is.na(poolsizes))>0){stop("ERROR: Please provide a vector of Pool Sizes (poolsize argument)")}
   if(min.dist.from.indels>0){remove.indels=TRUE}
   ##### Recup info and check validity of argument
   poolsizes=as.numeric(poolsizes)
-  if(verbose){cat("Reading Header lines\n")}
+  if(verbose){
+    cat("**********************\n")
+    cat("Reading Header lines\n")}
   file.con=file(vcf.file,open="r") 
   continue.reading=TRUE
   nlines.header=0
@@ -45,17 +46,32 @@ vcf2pooldata<-function(vcf.file="",poolsizes=NA,poolnames=NA,min.cov.per.pool=-1
       stop("ERROR: The vcf file is not valid. Could not find any header lines (i.e., starting with #CHROM)")}
   }
   npools=length(tmp.data)-9
-  if(length(poolsizes)!=npools){
-    close(file.con)
-    stop("ERROR: The number of pools in the vcf file is different from the length of the vector of pool sizes")}
+  #retrieve (or check dimension if provied) of sample names
   if(sum(is.na(poolnames))>0){
-    poolnames=paste0("Pool",1:npools)
+    poolnames=tmp.data[-(1:9)]
+    if(verbose){
+      cat("  *The following sample names for the",npools,"pools were retrieved from the vcf:\n")
+      print(poolnames)
+    }
   }else{
     poolnames=as.character(poolnames)
     if(length(poolnames)!=npools){
       close(file.con)
       stop("ERROR: The number of pools in the vcf file is different from the length of vector of pool names")}
   }
+  #give (or check dimension if provied) of haploid sample sizes
+  if(sum(is.na(poolsizes))>0){#set to a default value of 100
+    poolsizes=rep(100,npools) 
+    if(verbose){
+    cat("  *Warning: No pool sizes available from poolsizes argument\n  => the (haploid) pool size were set to an arbitrary default value of 100 for the",npools,"pools included in the vcf.\n")
+    cat("  !!!!Don't forget to update the slot @poolsizes of the output pooldata object if needed!!!!\n")
+    }
+  }else{#check if provided
+  if(length(poolsizes)!=npools){
+    close(file.con)
+    stop("ERROR: The number of pools in the vcf file is different from the length of the vector of pool sizes")}
+  }
+  #end specification of pools
   continue.reading=TRUE
   ######
   ##initalize output
@@ -85,12 +101,12 @@ vcf2pooldata<-function(vcf.file="",poolsizes=NA,poolnames=NA,min.cov.per.pool=-1
     if(length(rd.index)==0){
       VARSCAN=FALSE
       if(verbose){
-        cat("Standard format (i.e., as in Bcftools, GATK, etc.) detected for the AD field:\n the read count for all the identified alleles are separated by a comma\n")
+        cat("  *Standard format (i.e., as in FreeBayes, Bcftools, GATK, etc.) detected for the AD field:\n  the read count for all the identified alleles are separated by a comma\n")
       }
     }else{
       VARSCAN=TRUE
       if(verbose){
-        cat("VarScan like format detected for allele count data:\n the AD field contains allele depth\nfor the alternate allele and RD field for the reference allele\n(N.B., positions with more than one alternate allele will be ignored)\n")
+        cat("  *VarScan like format detected for allele count data:\n  the AD and RD fields contain allele depth for the alternate and reference alleles, respectively\n  (N.B., positions with more than one alternate allele will be ignored)\n")
       }
     }
   }
@@ -99,7 +115,9 @@ vcf2pooldata<-function(vcf.file="",poolsizes=NA,poolnames=NA,min.cov.per.pool=-1
   ##############
   time1=proc.time()
   nlines.read=0
-  if(verbose){cat("Parsing allele counts\n")}
+  if(verbose){
+    cat("**********************\n")
+    cat("Parsing allele counts\n")}
   while(continue.reading){
     tmp.data=matrix(scan(file=file.con,nlines = nlines.per.readblock,what="character",quiet=TRUE,quote=NULL),ncol=npools+9,byrow=T) 
     tmp.nlines.read=nrow(tmp.data)
@@ -180,6 +198,7 @@ vcf2pooldata<-function(vcf.file="",poolsizes=NA,poolnames=NA,min.cov.per.pool=-1
     }
   }
   close(file.con)
+  colnames(res@refallele.readcount)=colnames(res@readcoverage)=res@poolnames
   res@snp.info=data.frame(Chromosome=as.character(snpdet[,1]),
                           Position=as.numeric(snpdet[,2]),
                           RefAllele=as.character(snpdet[,3]),
